main(){
   INPUT_FOLDER=input
   OUTPUT_FOLDER=output

   create_folders
   download_salmonella_files
   fix_salmonella_fasta_headers
   filter_and_merge_salmonella_gff_files
   extract_salmonella_gene_and_locus_tags
   download_human_files
   fix_human_fasta_headers
   convert_human_gtf_to_gff
   extract_human_noncode_entries
   filter_noncode_entries
   combine_human_annotations_and_remove_redundancies
   download_pig_files
   combine_pig_fastas
   convert_pig_gtf_to_gff
   download_mouse_file
   extract_mouse_file
}

create_folders(){
    mkdir -p $INPUT_FOLDER $OUTPUT_FOLDER
}

download_salmonella_files(){
    # The files were orignally retrieved from
    # ftp://ftp.ncbi.nih.gov/genomes/Bacteria/Salmonella_enterica_serovar_Typhimurium_SL1344_uid86645/
    # NCBI has meanwhile changed their FTP server file organisation
    # and move the data to this archive folder.
    FTP_SOURCE=ftp://ftp.ncbi.nih.gov/genomes/archive/old_refseq/Bacteria/Salmonella_enterica_serovar_Typhimurium_SL1344_uid86645
    wget -P $INPUT_FOLDER/ \
	$FTP_SOURCE/*gff \
	$FTP_SOURCE/*fna
}

fix_salmonella_fasta_headers(){
    for FASTA_FILE in $(ls ${INPUT_FOLDER}/ | grep fna$)
    do
        ACCESSION=$(head -n 1 ${INPUT_FOLDER}/${FASTA_FILE} | cut -f 4 -d"|")
        cat ${INPUT_FOLDER}/${FASTA_FILE} | sed "s/>/>${ACCESSION} /" \
            > $OUTPUT_FOLDER/$(echo $FASTA_FILE | sed "s/.fna$/.fa/")
    done
}

filter_and_merge_salmonella_gff_files(){
    OUTPUT_FILE=$OUTPUT_FOLDER/Salmonella.gff
    echo "##gff-version 3" > $OUTPUT_FILE
    cat $INPUT_FOLDER/NC_01*.gff \
	| grep -v "#" \
        | grep -vP "\texon\t" \
        | grep -vP "\tgene\t" \
        | grep -vP "\tregion\t" \
        | grep -vP "\trepeat_region\t" \
        | grep -vP "\tSTS\t" \
        | grep -vP "\ttranscript\t" \
        >> $OUTPUT_FILE

cat << EOF >> ${OUTPUT_FILE}
NC_016810.1	misc_sources	sRNA	3985659	3986858	.	+	.	locus_tag=ncRNA0001;name=AmgR;status=confirmed
NC_016810.1	misc_sources	sRNA	3511800	3511918	.	+	.	locus_tag=ncRNA0002;name=ArcZ;status=confirmed
NC_016810.1	misc_sources	sRNA	555494	555573	.	+	.	locus_tag=ncRNA0003;name=ChiX;status=confirmed
NC_016810.1	misc_sources	sRNA	3636872	3636955	.	-	.	locus_tag=ncRNA0004;name=CrpT;status=confirmed
NC_016810.1	misc_sources	sRNA	3099171	3100233	.	-	.	locus_tag=ncRNA0005;name=crRNA1;status=confirmed
NC_016810.1	misc_sources	sRNA	3116271	3117792	.	-	.	locus_tag=ncRNA0006;name=crRNA2;status=confirmed
NC_016810.1	misc_sources	sRNA	3138161	3138522	.	-	.	locus_tag=ncRNA0007;name=CsrB;status=confirmed
NC_016810.1	misc_sources	sRNA	4231595	4231838	.	+	.	locus_tag=ncRNA0008;name=CsrC;status=confirmed
NC_016810.1	misc_sources	sRNA	2228847	2228931	.	+	.	locus_tag=ncRNA0009;name=CyaR;status=confirmed
NC_016810.1	misc_sources	sRNA	74847	74924	.	+	.	locus_tag=ncRNA0010;name=DapZ;status=confirmed
NC_016810.1	misc_sources	sRNA	2026216	2026303	.	-	.	locus_tag=ncRNA0011;name=DsrA;status=confirmed
NC_016810.1	misc_sources	sRNA	4672041	4672160	.	-	.	locus_tag=ncRNA0012;name=ECS021;status=candidate
NC_016810.1	misc_sources	sRNA	4404363	4404574	.	+	.	locus_tag=ncRNA0013;name=ECS173;status=candidate
NC_016810.1	misc_sources	sRNA	523911	524024	.	+	.	locus_tag=ncRNA0014;name=Ffs;status=confirmed
NC_016810.1	misc_sources	sRNA	1706784	1706905	.	-	.	locus_tag=ncRNA0015;name=FnrS;status=confirmed
NC_016810.1	misc_sources	sRNA	3156779	3156984	.	+	.	locus_tag=ncRNA0016;name=GcvB;status=confirmed
NC_016810.1	misc_sources	sRNA	2705381	2705564	.	-	.	locus_tag=ncRNA0017;name=GlmY;status=confirmed
NC_016810.1	misc_sources	sRNA	4163192	4163399	.	+	.	locus_tag=ncRNA0018;name=GlmZ;status=confirmed
NC_016810.1	misc_sources	sRNA	3489916	3489970	.	-	.	locus_tag=ncRNA0019;name=GraL;status=confirmed
NC_016810.1	misc_sources	sRNA	1550136	1550213	.	-	.	locus_tag=ncRNA0020;name=Ig959;status=candidate
NC_016810.1	misc_sources	sRNA	1358936	1359182	.	+	.	locus_tag=ncRNA0021;name=Ig1085;status=candidate
NC_016810.1	misc_sources	sRNA	1880774	1880889	.	+	.	locus_tag=ncRNA0022;name=Ig1140;status=candidate
NC_016810.1	misc_sources	sRNA	4162241	4162392	.	+	.	locus_tag=ncRNA0023;name=Ig2335;status=candidate
NC_016810.1	misc_sources	sRNA	1113719	1113828	.	-	.	locus_tag=ncRNA0024;name=IS042;status=candidate
NC_016810.1	misc_sources	sRNA	3067499	3067586	.	+	.	locus_tag=ncRNA0025;name=InvR;status=confirmed
NC_016810.1	misc_sources	sRNA	338816	339238	.	+	.	locus_tag=ncRNA0026;name=IsrA;status=confirmed
NC_016810.1	misc_sources	sRNA	1060741	1060834	.	+	.	locus_tag=ncRNA0027;name=IsrB;status=confirmed
NC_016810.1	misc_sources	sRNA	1285997	1286284	.	+	.	locus_tag=ncRNA0028;name=IsrC;status=confirmed
NC_016810.1	misc_sources	sRNA	1302592	1302640	.	-	.	locus_tag=ncRNA0029;name=IsrD;status=confirmed
NC_016810.1	misc_sources	sRNA	1309727	1309824	.	-	.	locus_tag=ncRNA0030;name=IsrE;status=confirmed
NC_016810.1	misc_sources	sRNA	1586723	1587018	.	-	.	locus_tag=ncRNA0031;name=IsrF;status=confirmed
NC_016810.1	misc_sources	sRNA	2342448	2342729	.	+	.	locus_tag=ncRNA0032;name=IsrG;status=confirmed
NC_016810.1	misc_sources	sRNA	2392019	2392468	.	-	.	locus_tag=ncRNA0033;name=IsrH-1;status=confirmed
NC_016810.1	misc_sources	sRNA	2392019	2392298	.	-	.	locus_tag=ncRNA0034;name=IsrH-2;status=confirmed
NC_016810.1	misc_sources	sRNA	2759016	2759270	.	-	.	locus_tag=ncRNA0035;name=IsrI;status=confirmed
NC_016810.1	misc_sources	sRNA	2759644	2759718	.	-	.	locus_tag=ncRNA0036;name=IsrJ;status=confirmed
NC_016810.1	misc_sources	sRNA	2760478	2760556	.	-	.	locus_tag=ncRNA0037;name=IsrK;status=confirmed
NC_016810.1	misc_sources	sRNA	2850243	2850587	.	-	.	locus_tag=ncRNA0038;name=IsrL;status=confirmed
NC_016810.1	misc_sources	sRNA	2927612	2927944	.	+	.	locus_tag=ncRNA0039;name=IsrM;status=confirmed
NC_016810.1	misc_sources	sRNA	2929501	2929643	.	+	.	locus_tag=ncRNA0040;name=IsrN;status=confirmed
NC_016810.1	misc_sources	sRNA	3219100	3219300	.	+	.	locus_tag=ncRNA0041;name=IsrO;status=confirmed
NC_016810.1	misc_sources	sRNA	4328157	4328305	.	+	.	locus_tag=ncRNA0042;name=IsrP;status=confirmed
NC_016810.1	misc_sources	sRNA	4783574	4783741	.	+	.	locus_tag=ncRNA0043;name=IsrQ;status=confirmed
NC_016810.1	misc_sources	sRNA	4019328	4019404	.	-	.	locus_tag=ncRNA0044;name=IstR-1;status=confirmed
NC_016810.1	misc_sources	sRNA	4019328	4019458	.	-	.	locus_tag=ncRNA0045;name=IstR-2;status=confirmed
NC_016810.1	misc_sources	sRNA	1550746	1550843	.	+	.	locus_tag=ncRNA0046;name=MgrR;status=confirmed
NC_016810.1	misc_sources	sRNA	2989429	2989505	.	+	.	locus_tag=ncRNA0047;name=MicA;status=confirmed
NC_016810.1	misc_sources	sRNA	1702529	1702639	.	-	.	locus_tag=ncRNA0048;name=MicC;status=confirmed
NC_016810.1	misc_sources	sRNA	2364629	2364721	.	+	.	locus_tag=ncRNA0049;name=MicF;status=confirmed
NC_016810.1	misc_sources	sRNA	4072486	4072528	.	+	.	locus_tag=ncRNA0050;name=Msr;status=confirmed
NC_016810.1	misc_sources	sRNA	3191584	3191670	.	-	.	locus_tag=ncRNA0051;name=OmrA;status=confirmed
NC_016810.1	misc_sources	sRNA	3191786	3191870	.	-	.	locus_tag=ncRNA0052;name=OmrB;status=confirmed
NC_016810.1	misc_sources	sRNA	4364306	4364423	.	-	.	locus_tag=ncRNA0053;name=OxyS;status=confirmed
NC_016810.1	misc_sources	sRNA	3242849	3242861	.	-	.	locus_tag=ncRNA0054;name=pRNA;status=confirmed
NC_016810.1	misc_sources	sRNA	1287312	1287455	.	-	.	locus_tag=ncRNA0055;name=RaoN;status=confirmed
NC_016810.1	misc_sources	sRNA	3829661	3829727	.	+	.	locus_tag=ncRNA0056;name=RdlD;status=confirmed
NC_016810.1	misc_sources	sRNA	466718	466783	.	-	.	locus_tag=ncRNA0057;name=RdlE;status=confirmed
NC_016810.1	misc_sources	sRNA	3435508	3435882	.	-	.	locus_tag=ncRNA0058;name=RnpB;status=confirmed
NC_016810.1	misc_sources	sRNA	1401685	1401790	.	-	.	locus_tag=ncRNA0059;name=RprA;status=confirmed
NC_016810.1	misc_sources	sRNA	2034772	2034837	.	+	.	locus_tag=ncRNA0060;name=RseX;status=confirmed
NC_016810.1	misc_sources	sRNA	901188	901397	.	-	.	locus_tag=ncRNA0061;name=RybA;status=confirmed
NC_016810.1	misc_sources	sRNA	941813	941893	.	-	.	locus_tag=ncRNA0062;name=RybB;status=confirmed
NC_016810.1	misc_sources	sRNA	807346	807433	.	+	.	locus_tag=ncRNA0063;name=RybD;status=confirmed
NC_016810.1	misc_sources	sRNA	1407278	1407375	.	+	.	locus_tag=ncRNA0064;name=RydB;status=confirmed
NC_016810.1	misc_sources	sRNA	1686527	1686590	.	+	.	locus_tag=ncRNA0065;name=RydC;status=confirmed
NC_016810.1	misc_sources	sRNA	1958513	1958819	.	-	.	locus_tag=ncRNA0066;name=RyeF;status=confirmed
NC_016810.1	misc_sources	sRNA	2672651	2672945	.	+	.	locus_tag=ncRNA0067;name=RyfA;status=confirmed
NC_016810.1	misc_sources	sRNA	2805082	2805222	.	-	.	locus_tag=ncRNA0068;name=RyfD;status=confirmed
NC_016810.1	misc_sources	sRNA	3736723	3736817	.	-	.	locus_tag=ncRNA0069;name=RyhB;status=confirmed
NC_016810.1	misc_sources	sRNA	1662190	1662282	.	-	.	locus_tag=ncRNA0070;name=RyjB;status=confirmed
NC_016810.1	misc_sources	sRNA	2071343	2071409	.	+	.	locus_tag=ncRNA0071;name=Sar;status=confirmed
NC_016810.1	misc_sources	sRNA	1925621	1925723	.	-	.	locus_tag=ncRNA0072;name=SdsR;status=confirmed
NC_016810.1	misc_sources	sRNA	128577	128815	.	+	.	locus_tag=ncRNA0073;name=SgrS;status=confirmed
NC_016810.1	misc_sources	sRNA	2211623	2211781	.	+	.	locus_tag=ncRNA0074;name=SibA;status=confirmed
NC_016810.1	misc_sources	sRNA	3243669	3243814	.	+	.	locus_tag=ncRNA0075;name=SibC;status=confirmed
NC_016810.1	misc_sources	sRNA	3382993	3383144	.	-	.	locus_tag=ncRNA0076;name=SibD;status=confirmed
NC_016810.1	misc_sources	sRNA	4230504	4230612	.	+	.	locus_tag=ncRNA0077;name=Spf;status=confirmed
NC_016810.1	misc_sources	sRNA	504869	504976	.	-	.	locus_tag=ncRNA0078;name=SraA;status=confirmed
NC_016810.1	misc_sources	sRNA	1231270	1231378	.	+	.	locus_tag=ncRNA0079;name=SraB;status=confirmed
NC_016810.1	misc_sources	sRNA	1925543	1925852	.	+	.	locus_tag=ncRNA0080;name=SraC;status=confirmed
NC_016810.1	misc_sources	sRNA	3412774	3412960	.	+	.	locus_tag=ncRNA0081;name=SraF;status=confirmed
NC_016810.1	misc_sources	sRNA	3472128	3472312	.	+	.	locus_tag=ncRNA0082;name=SraG;status=confirmed
NC_016810.1	misc_sources	sRNA	4526162	4526302	.	-	.	locus_tag=ncRNA0083;name=SraL;status=confirmed
NC_016810.1	misc_sources	sRNA	126714	126802	.	-	.	locus_tag=ncRNA0084;name=SroA;status=confirmed
NC_016810.1	misc_sources	sRNA	728173	728327	.	-	.	locus_tag=ncRNA0085;name=SroC;status=confirmed
NC_016810.1	misc_sources	sRNA	1872740	1872842	.	-	.	locus_tag=ncRNA0086;name=SroD;status=confirmed
NC_016810.1	misc_sources	sRNA	3379213	3379513	.	-	.	locus_tag=ncRNA0087;name=SroG;status=confirmed
NC_016810.1	misc_sources	sRNA	2855136	2855498	.	+	.	locus_tag=ncRNA0088;name=SsrA;status=confirmed
NC_016810.1	misc_sources	sRNA	3242819	3243000	.	+	.	locus_tag=ncRNA0089;name=SsrS;status=confirmed
NC_016810.1	misc_sources	sRNA	4797969	4798032	.	+	.	locus_tag=ncRNA0090;name=SymR;status=confirmed
NC_016810.1	misc_sources	sRNA	254126	254276	.	+	.	locus_tag=ncRNA0091;name=Tff;status=confirmed
NC_016810.1	misc_sources	sRNA	3704122	3704235	.	-	.	locus_tag=ncRNA0092;name=YrlA;status=confirmed
NC_016810.1	misc_sources	sRNA	3704353	3704443	.	-	.	locus_tag=ncRNA0093;name=YrlB;status=confirmed
NC_016810.1	misc_sources	sRNA	176086	176242	.	-	.	locus_tag=ncRNA0094;name=tp2;status=confirmed
NC_016810.1	misc_sources	sRNA	756377	756432	.	-	.	locus_tag=ncRNA0095;name=tp28;status=candidate
NC_016810.1	misc_sources	sRNA	4238588	4238764	.	+	.	locus_tag=ncRNA0096;name=tpk3;status=confirmed
NC_016810.1	misc_sources	sRNA	13514	13576	.	+	.	locus_tag=ncRNA0097;name=tpke11;status=confirmed
NC_016810.1	misc_sources	sRNA	2513324	2513722	.	-	.	locus_tag=ncRNA0098;name=tpke70;status=confirmed
NC_016810.1	misc_sources	sRNA	4461058	4461442	.	-	.	locus_tag=ncRNA0099;name=lysC-leader;status=confirmed
NC_016810.1	misc_sources	sRNA	3566010	3566249	.	-	.	locus_tag=ncRNA0100;name=mreB-leader;status=confirmed
NC_016810.1	misc_sources	sRNA	3624232	3624439	.	-	.	locus_tag=ncRNA0101;name=rpsL-leader;status=confirmed
NC_016810.1	misc_sources	sRNA	2828093	2828145	.	-	.	locus_tag=ncRNA0102;name=rpsP-leader;status=confirmed
NC_016810.1	misc_sources	sRNA	2539669	2539837	.	-	.	locus_tag=ncRNA0103;name=zipA-leader;status=confirmed
NC_016810.1	misc_sources	sRNA	604162	604211	.	+	.	locus_tag=ncRNA0104;name=fimA-trailer;status=confirmed
NC_016810.1	misc_sources	sRNA	3603180	3603249	.	+	.	locus_tag=ncRNA0105;name=asarfA;status=candidate
NC_016810.1	misc_sources	sRNA	3459586	3459745	.	-	.	locus_tag=ncRNA0106;name=asyhbQ;status=candidate
NC_016810.1	misc_sources	sRNA	3515280	3515360	.	+	.	locus_tag=ncRNA0107;name=GO-10702;status=candidate
NC_016810.1	misc_sources	sRNA	4179408	4179646	.	+	.	locus_tag=ncRNA0108;name=GO-10704;status=candidate
NC_016810.1	misc_sources	sRNA	257717	257816	.	+	.	locus_tag=ncRNA0109;name=sRNA1;status=confirmed
NC_016810.1	misc_sources	sRNA	2311208	2311408	.	+	.	locus_tag=ncRNA0110;name=sRNA2;status=candidate
NC_016810.1	misc_sources	sRNA	4617695	4617761	.	+	.	locus_tag=ncRNA0111;name=sRNA5;status=candidate
NC_016810.1	misc_sources	sRNA	3295804	3295990	.	-	.	locus_tag=ncRNA0112;name=sRNA7;status=candidate
NC_016810.1	misc_sources	sRNA	679292	679410	.	-	.	locus_tag=ncRNA0113;name=sRNA10;status=confirmed
NC_016810.1	misc_sources	sRNA	139457	139729	.	+	.	locus_tag=ncRNA0114;name=sRNA11;status=candidate
NC_016810.1	misc_sources	sRNA	3755044	3755124	.	-	.	locus_tag=ncRNA0115;name=sRNA12;status=confirmed
NC_016810.1	misc_sources	sRNA	1648525	1648804	.	+	.	locus_tag=ncRNA0116;name=sRNA15;status=candidate
NC_016810.1	misc_sources	sRNA	1291395	1291605	.	-	.	locus_tag=ncRNA0117;name=sRNA16;status=candidate
NC_016810.1	misc_sources	sRNA	691416	691466	.	+	.	locus_tag=ncRNA0118;name=sRNA18;status=candidate
NC_016810.1	misc_sources	sRNA	2631708	2631786	.	+	.	locus_tag=ncRNA0119;name=sRNA19;status=candidate
NC_016810.1	misc_sources	sRNA	4582490	4583009	.	+	.	locus_tag=ncRNA0120;name=sRNA21;status=candidate
NC_016810.1	misc_sources	sRNA	3549920	3550072	.	-	.	locus_tag=ncRNA0121;name=sRNA22;status=candidate
NC_016810.1	misc_sources	sRNA	3495784	3495897	.	-	.	locus_tag=ncRNA0122;name=sRNA23;status=candidate
NC_016810.1	misc_sources	sRNA	2114336	2114409	.	-	.	locus_tag=ncRNA0123;name=sRNA24;status=candidate
NC_016810.1	misc_sources	sRNA	1584389	1584661	.	-	.	locus_tag=ncRNA0124;name=sRNA25;status=candidate
NC_016810.1	misc_sources	sRNA	75473	75557	.	+	.	locus_tag=ncRNA0125;name=sRNA26;status=candidate
NC_016810.1	misc_sources	sRNA	230133	230365	.	+	.	locus_tag=ncRNA0126;name=sRNA28;status=candidate
NC_016810.1	misc_sources	sRNA	4336600	4336886	.	-	.	locus_tag=ncRNA0127;name=sRNA29;status=candidate
NC_016810.1	misc_sources	sRNA	3576378	3576534	.	-	.	locus_tag=ncRNA0128;name=sRNA31;status=candidate
NC_016810.1	misc_sources	sRNA	610437	610589	.	-	.	locus_tag=ncRNA0129;name=sRNA32;status=candidate
NC_016810.1	misc_sources	sRNA	3550031	3550308	.	-	.	locus_tag=ncRNA0130;name=sRNA33;status=candidate
NC_016810.1	misc_sources	sRNA	46050	46114	.	-	.	locus_tag=ncRNA0131;name=STnc10;status=candidate
NC_016810.1	misc_sources	sRNA	52094	52272	.	+	.	locus_tag=ncRNA0132;name=STnc20;status=candidate
NC_016810.1	misc_sources	sRNA	58792	58923	.	+	.	locus_tag=ncRNA0133;name=STnc30;status=candidate
NC_016810.1	misc_sources	sRNA	161417	161558	.	+	.	locus_tag=ncRNA0134;name=STnc40;status=candidate
NC_016810.1	misc_sources	sRNA	182462	182543	.	-	.	locus_tag=ncRNA0135;name=STnc50;status=candidate
NC_016810.1	misc_sources	sRNA	230168	230221	.	-	.	locus_tag=ncRNA0136;name=STnc60;status=candidate
NC_016810.1	misc_sources	sRNA	669616	669786	.	+	.	locus_tag=ncRNA0137;name=STnc70;status=candidate
NC_016810.1	misc_sources	sRNA	1001645	1001760	.	-	.	locus_tag=ncRNA0138;name=STnc130;status=candidate
NC_016810.1	misc_sources	sRNA	1070213	1070327	.	+	.	locus_tag=ncRNA0139;name=STnc140;status=candidate
NC_016810.1	misc_sources	sRNA	1282503	1282686	.	-	.	locus_tag=ncRNA0140;name=STnc150;status=confirmed
NC_016810.1	misc_sources	sRNA	1562637	1562969	.	-	.	locus_tag=ncRNA0141;name=STnc170;status=candidate
NC_016810.1	misc_sources	sRNA	1895063	1895216	.	+	.	locus_tag=ncRNA0142;name=STnc190;status=candidate
NC_016810.1	misc_sources	sRNA	1937123	1937193	.	-	.	locus_tag=ncRNA0143;name=STnc200;status=candidate
NC_016810.1	misc_sources	sRNA	1974403	1974566	.	-	.	locus_tag=ncRNA0144;name=STnc205;status=candidate
NC_016810.1	misc_sources	sRNA	1989987	1990148	.	+	.	locus_tag=ncRNA0145;name=STnc210;status=candidate
NC_016810.1	misc_sources	sRNA	2036562	2036659	.	-	.	locus_tag=ncRNA0146;name=STnc220;status=candidate
NC_016810.1	misc_sources	sRNA	2113060	2113174	.	+	.	locus_tag=ncRNA0147;name=STnc230;status=candidate
NC_016810.1	misc_sources	sRNA	2145050	2145161	.	-	.	locus_tag=ncRNA0148;name=STnc240;status=candidate
NC_016810.1	misc_sources	sRNA	2988649	2988823	.	+	.	locus_tag=ncRNA0149;name=STnc260;status=candidate
NC_016810.1	misc_sources	sRNA	3200938	3201079	.	+	.	locus_tag=ncRNA0150;name=STnc280;status=candidate
NC_016810.1	misc_sources	sRNA	3215639	3215781	.	-	.	locus_tag=ncRNA0151;name=STnc290;status=confirmed
NC_016810.1	misc_sources	sRNA	3304510	3304577	.	-	.	locus_tag=ncRNA0152;name=STnc300;status=candidate
NC_016810.1	misc_sources	sRNA	3413966	3414055	.	-	.	locus_tag=ncRNA0153;name=STnc310;status=candidate
NC_016810.1	misc_sources	sRNA	3425410	3425649	.	+	.	locus_tag=ncRNA0154;name=STnc320;status=candidate
NC_016810.1	misc_sources	sRNA	3657244	3657392	.	-	.	locus_tag=ncRNA0155;name=STnc340;status=candidate
NC_016810.1	misc_sources	sRNA	3782700	3782856	.	-	.	locus_tag=ncRNA0156;name=STnc350;status=candidate
NC_016810.1	misc_sources	sRNA	3801579	3801727	.	+	.	locus_tag=ncRNA0157;name=STnc360;status=candidate
NC_016810.1	misc_sources	sRNA	3861003	3861073	.	+	.	locus_tag=ncRNA0158;name=STnc370;status=candidate
NC_016810.1	misc_sources	sRNA	3906944	3907051	.	-	.	locus_tag=ncRNA0159;name=STnc380;status=candidate
NC_016810.1	misc_sources	sRNA	3923913	3923975	.	-	.	locus_tag=ncRNA0160;name=STnc390;status=candidate
NC_016810.1	misc_sources	sRNA	4093818	4094041	.	+	.	locus_tag=ncRNA0161;name=STnc410;status=candidate
NC_016810.1	misc_sources	sRNA	4272916	4272977	.	-	.	locus_tag=ncRNA0162;name=STnc420;status=candidate
NC_016810.1	misc_sources	sRNA	4463194	4463343	.	-	.	locus_tag=ncRNA0163;name=STnc430;status=candidate
NC_016810.1	misc_sources	sRNA	4580485	4580565	.	+	.	locus_tag=ncRNA0164;name=pinT;status=confirmed
NC_016810.1	misc_sources	sRNA	4665599	4665699	.	-	.	locus_tag=ncRNA0165;name=STnc450;status=candidate
NC_016810.1	misc_sources	sRNA	4778770	4778915	.	-	.	locus_tag=ncRNA0166;name=STnc460;status=candidate
NC_016810.1	misc_sources	sRNA	94653	94771	.	-	.	locus_tag=ncRNA0167;name=STnc470;status=confirmed
NC_016810.1	misc_sources	sRNA	142801	142976	.	+	.	locus_tag=ncRNA0168;name=STnc475;status=candidate
NC_016810.1	misc_sources	sRNA	587340	587395	.	-	.	locus_tag=ncRNA0169;name=STnc480;status=candidate
NC_016810.1	misc_sources	sRNA	981624	981711	.	-	.	locus_tag=ncRNA0170;name=STnc490a;status=confirmed
NC_016810.1	misc_sources	sRNA	1270920	1271007	.	-	.	locus_tag=ncRNA0171;name=STnc490b;status=confirmed
NC_016810.1	misc_sources	sRNA	1872588	1872675	.	+	.	locus_tag=ncRNA0172;name=STnc490c;status=confirmed
NC_016810.1	misc_sources	sRNA	2003753	2003840	.	+	.	locus_tag=ncRNA0173;name=STnc490d;status=confirmed
NC_016810.1	misc_sources	sRNA	2577497	2577584	.	+	.	locus_tag=ncRNA0174;name=STnc490e;status=confirmed
NC_016810.1	misc_sources	sRNA	3485887	3485974	.	+	.	locus_tag=ncRNA0175;name=STnc490f;status=confirmed
NC_016810.1	misc_sources	sRNA	3657129	3657216	.	+	.	locus_tag=ncRNA0176;name=STnc490g;status=confirmed
NC_016810.1	misc_sources	sRNA	1172561	1172641	.	-	.	locus_tag=ncRNA0177;name=STnc500;status=confirmed
NC_016810.1	misc_sources	sRNA	1288534	1289103	.	+	.	locus_tag=ncRNA0178;name=STnc510;status=candidate
NC_016810.1	misc_sources	sRNA	1290590	1290674	.	-	.	locus_tag=ncRNA0179;name=STnc520;status=confirmed
NC_016810.1	misc_sources	sRNA	1317058	1317158	.	-	.	locus_tag=ncRNA0180;name=STnc530;status=candidate
NC_016810.1	misc_sources	sRNA	1376238	1376364	.	+	.	locus_tag=ncRNA0181;name=STnc540;status=confirmed
NC_016810.1	misc_sources	sRNA	3033415	3033542	.	-	.	locus_tag=ncRNA0182;name=STnc590;status=candidate
NC_016810.1	misc_sources	sRNA	3041345	3041651	.	+	.	locus_tag=ncRNA0183;name=STnc600;status=candidate
NC_016810.1	misc_sources	sRNA	3479058	3479185	.	-	.	locus_tag=ncRNA0184;name=STnc610;status=candidate
NC_016810.1	misc_sources	sRNA	4498083	4498195	.	+	.	locus_tag=ncRNA0185;name=STnc620;status=candidate
NC_016810.1	misc_sources	sRNA	1282751	1282935	.	+	.	locus_tag=ncRNA0186;name=STnc640;status=candidate
NC_016810.1	misc_sources	sRNA	898557	898793	.	+	.	locus_tag=ncRNA0187;name=STnc650;status=candidate
NC_016810.1	misc_sources	sRNA	1065576	1065670	.	+	.	locus_tag=ncRNA0188;name=STnc660;status=candidate
NC_016810.1	misc_sources	sRNA	1170291	1170591	.	+	.	locus_tag=ncRNA0189;name=STnc670;status=candidate
NC_016810.1	misc_sources	sRNA	1242408	1242503	.	+	.	locus_tag=ncRNA0190;name=STnc680;status=candidate
NC_016810.1	misc_sources	sRNA	2082026	2082107	.	+	.	locus_tag=ncRNA0191;name=STnc690;status=candidate
NC_016810.1	misc_sources	sRNA	2146261	2146324	.	-	.	locus_tag=ncRNA0192;name=STnc695;status=candidate
NC_016810.1	misc_sources	sRNA	1295333	1295432	.	-	.	locus_tag=ncRNA0193;name=STnc720;status=candidate
NC_016810.1	misc_sources	sRNA	1462356	1462446	.	-	.	locus_tag=ncRNA0194;name=STnc730;status=confirmed
NC_016810.1	misc_sources	sRNA	2240284	2240365	.	-	.	locus_tag=ncRNA0195;name=STnc740;status=confirmed
NC_016810.1	misc_sources	sRNA	3261186	3261273	.	-	.	locus_tag=ncRNA0196;name=STnc750;status=confirmed
NC_016810.1	misc_sources	sRNA	3684981	3685117	.	-	.	locus_tag=ncRNA0197;name=STnc760;status=confirmed
NC_016810.1	misc_sources	sRNA	3778180	3778332	.	-	.	locus_tag=ncRNA0198;name=STnc770;status=confirmed
NC_016810.1	misc_sources	sRNA	3858678	3858992	.	-	.	locus_tag=ncRNA0199;name=STnc780;status=confirmed
NC_016810.1	misc_sources	sRNA	4209502	4209698	.	-	.	locus_tag=ncRNA0200;name=STnc790;status=candidate
NC_016810.1	misc_sources	sRNA	4236852	4237032	.	-	.	locus_tag=ncRNA0201;name=STnc800;status=candidate
NC_016810.1	misc_sources	sRNA	4467936	4467989	.	-	.	locus_tag=ncRNA0202;name=STnc810;status=candidate
NC_016810.1	misc_sources	sRNA	817257	817293	.	+	.	locus_tag=ncRNA0203;name=STnc835;status=candidate
NC_016810.1	misc_sources	sRNA	1224246	1224318	.	+	.	locus_tag=ncRNA0204;name=STnc840;status=confirmed
NC_016810.1	misc_sources	sRNA	1252605	1252674	.	+	.	locus_tag=ncRNA0205;name=STnc850;status=confirmed
NC_016810.1	misc_sources	sRNA	4292542	4292599	.	+	.	locus_tag=ncRNA0206;name=STnc870;status=confirmed
NC_016810.1	misc_sources	sRNA	4486745	4486825	.	+	.	locus_tag=ncRNA0207;name=STnc880;status=candidate
NC_016810.1	misc_sources	sRNA	14722	14786	.	+	.	locus_tag=ncRNA0208;name=STnc890;status=candidate
NC_016810.1	misc_sources	sRNA	259068	259166	.	+	.	locus_tag=ncRNA0209;name=STnc920;status=candidate
NC_016810.1	misc_sources	sRNA	285917	285972	.	-	.	locus_tag=ncRNA0210;name=STnc925;status=candidate
NC_016810.1	misc_sources	sRNA	514486	514580	.	+	.	locus_tag=ncRNA0211;name=STnc930;status=confirmed
NC_016810.1	misc_sources	sRNA	569013	569075	.	+	.	locus_tag=ncRNA0212;name=STnc940;status=candidate
NC_016810.1	misc_sources	sRNA	573181	573240	.	+	.	locus_tag=ncRNA0213;name=STnc950;status=candidate
NC_016810.1	misc_sources	sRNA	889560	889716	.	-	.	locus_tag=ncRNA0214;name=STnc970;status=candidate
NC_016810.1	misc_sources	sRNA	41629	41707	.	+	.	locus_tag=ncRNA0215;name=STnc1010;status=confirmed
NC_016810.1	misc_sources	sRNA	350913	351102	.	+	.	locus_tag=ncRNA0216;name=STnc1030;status=candidate
NC_016810.1	misc_sources	sRNA	350914	351100	.	-	.	locus_tag=ncRNA0217;name=STnc1040;status=confirmed
NC_016810.1	misc_sources	sRNA	497375	497538	.	-	.	locus_tag=ncRNA0218;name=STnc1065;status=candidate
NC_016810.1	misc_sources	sRNA	974644	974892	.	+	.	locus_tag=ncRNA0219;name=STnc1070;status=candidate
NC_016810.1	misc_sources	sRNA	1062745	1062806	.	-	.	locus_tag=ncRNA0220;name=STnc1080;status=confirmed
NC_016810.1	misc_sources	sRNA	1252560	1252626	.	-	.	locus_tag=ncRNA0221;name=STnc1090;status=confirmed
NC_016810.1	misc_sources	sRNA	1435601	1435729	.	+	.	locus_tag=ncRNA0222;name=STnc1100;status=candidate
NC_016810.1	misc_sources	sRNA	1913612	1913755	.	-	.	locus_tag=ncRNA0223;name=STnc1130;status=candidate
NC_016810.1	misc_sources	sRNA	2222979	2223134	.	+	.	locus_tag=ncRNA0224;name=STnc1150;status=confirmed
NC_016810.1	misc_sources	sRNA	2760372	2760451	.	-	.	locus_tag=ncRNA0225;name=STnc1160;status=confirmed
NC_016810.1	misc_sources	sRNA	3312426	3312492	.	-	.	locus_tag=ncRNA0226;name=STnc1170;status=candidate
NC_016810.1	misc_sources	sRNA	4559883	4559976	.	-	.	locus_tag=ncRNA0227;name=STnc1180;status=confirmed
NC_016810.1	misc_sources	sRNA	4601021	4601437	.	+	.	locus_tag=ncRNA0228;name=STnc1190;status=candidate
NC_016810.1	misc_sources	sRNA	924756	924838	.	-	.	locus_tag=ncRNA0229;name=STnc1200;status=candidate
NC_016810.1	misc_sources	sRNA	1292947	1293012	.	+	.	locus_tag=ncRNA0230;name=STnc1210;status=confirmed
NC_016810.1	misc_sources	sRNA	1448718	1448790	.	-	.	locus_tag=ncRNA0231;name=STnc1220;status=confirmed
NC_016810.1	misc_sources	sRNA	1992503	1992663	.	-	.	locus_tag=ncRNA0232;name=STnc1275;status=candidate
NC_016810.1	misc_sources	sRNA	2039988	2040056	.	+	.	locus_tag=ncRNA0233;name=STnc1280;status=candidate
NC_016810.1	misc_sources	sRNA	2002640	2002727	.	-	.	locus_tag=ncRNA0234;name=STnc1285;status=candidate
NC_016810.1	misc_sources	sRNA	2070802	2070885	.	-	.	locus_tag=ncRNA0235;name=STnc1290;status=confirmed
NC_016810.1	misc_sources	sRNA	2174386	2174466	.	+	.	locus_tag=ncRNA0236;name=STnc1320;status=candidate
NC_016810.1	misc_sources	sRNA	2319950	2320037	.	-	.	locus_tag=ncRNA0237;name=STnc1340;status=confirmed
NC_016810.1	misc_sources	sRNA	2729634	2729701	.	-	.	locus_tag=ncRNA0238;name=STnc1380;status=confirmed
NC_016810.1	misc_sources	sRNA	2747046	2747185	.	+	.	locus_tag=ncRNA0239;name=STnc1385;status=confirmed
NC_016810.1	misc_sources	sRNA	2767704	2767767	.	+	.	locus_tag=ncRNA0240;name=STnc1390;status=confirmed
NC_016810.1	misc_sources	sRNA	2770951	2771060	.	-	.	locus_tag=ncRNA0241;name=STnc1400;status=confirmed
NC_016810.1	misc_sources	sRNA	3038069	3038192	.	-	.	locus_tag=ncRNA0242;name=STnc1405;status=candidate
NC_016810.1	misc_sources	sRNA	3048830	3048931	.	+	.	locus_tag=ncRNA0243;name=STnc1410;status=candidate
NC_016810.1	misc_sources	sRNA	4403810	4404049	.	-	.	locus_tag=ncRNA0244;name=STnc1460;status=confirmed
NC_016810.1	misc_sources	sRNA	2953269	2953441	.	+	.	locus_tag=ncRNA0245;name=STnc1490;status=candidate
NC_016810.1	misc_sources	sRNA	138100	138274	.	-	.	locus_tag=ncRNA0246;name=STnc1500;status=candidate
NC_016810.1	misc_sources	sRNA	237091	237187	.	+	.	locus_tag=ncRNA0247;name=STnc1510;status=candidate
NC_016810.1	misc_sources	sRNA	2101640	2101726	.	+	.	locus_tag=ncRNA0248;name=STnc1530;status=candidate
NC_016810.1	misc_sources	sRNA	2321040	2321137	.	-	.	locus_tag=ncRNA0249;name=STnc1540;status=candidate
NC_016810.1	misc_sources	sRNA	2372043	2372177	.	-	.	locus_tag=ncRNA0250;name=STnc1545;status=candidate
NC_016810.1	misc_sources	sRNA	2437665	2437808	.	+	.	locus_tag=ncRNA0251;name=STnc1550;status=candidate
NC_016810.1	misc_sources	sRNA	2449088	2449184	.	+	.	locus_tag=ncRNA0252;name=STnc1560;status=candidate
NC_016810.1	misc_sources	sRNA	2488465	2488645	.	+	.	locus_tag=ncRNA0253;name=STnc1565;status=candidate
NC_016810.1	misc_sources	sRNA	3633254	3633328	.	+	.	locus_tag=ncRNA0254;name=STnc1580;status=candidate
NC_016810.1	misc_sources	sRNA	3633247	3633424	.	-	.	locus_tag=ncRNA0255;name=STnc1590;status=confirmed
NC_016810.1	misc_sources	sRNA	4356616	4356686	.	+	.	locus_tag=ncRNA0256;name=STnc1600;status=confirmed
NC_016810.1	misc_sources	sRNA	1345903	1345970	.	+	.	locus_tag=ncRNA0257;name=STnc1640;status=confirmed
NC_016810.1	misc_sources	sRNA	2133038	2133100	.	+	.	locus_tag=ncRNA0258;name=STnc1650;status=confirmed
NC_016810.1	misc_sources	sRNA	3489125	3489247	.	-	.	locus_tag=ncRNA0259;name=STnc1660;status=candidate
NC_016810.1	misc_sources	sRNA	3593794	3593888	.	+	.	locus_tag=ncRNA0260;name=STnc1670;status=candidate
NC_016810.1	misc_sources	sRNA	3604974	3605468	.	-	.	locus_tag=ncRNA0261;name=STnc1675;status=candidate
NC_016810.1	misc_sources	sRNA	2897019	2897102	.	+	.	locus_tag=ncRNA0262;name=STnc1680;status=confirmed
NC_016810.1	misc_sources	sRNA	2936814	2937274	.	-	.	locus_tag=ncRNA0263;name=STnc1685;status=candidate
NC_016810.1	misc_sources	sRNA	1931467	1931545	.	+	.	locus_tag=ncRNA0264;name=STnc1690;status=candidate
NC_016810.1	misc_sources	sRNA	386380	386476	.	+	.	locus_tag=ncRNA0265;name=STnc1700;status=candidate
NC_016810.1	misc_sources	sRNA	932197	932336	.	+	.	locus_tag=ncRNA0266;name=STnc1710;status=candidate
NC_016810.1	misc_sources	sRNA	1292835	1292935	.	-	.	locus_tag=ncRNA0267;name=STnc1760;status=candidate
NC_016810.1	misc_sources	sRNA	3349047	3349187	.	-	.	locus_tag=ncRNA0268;name=STnc1820;status=candidate
NC_016810.1	misc_sources	sRNA	3739677	3739897	.	-	.	locus_tag=ncRNA0269;name=STnc1830;status=candidate
NC_016810.1	misc_sources	sRNA	617317	617426	.	+	.	locus_tag=ncRNA0270;name=STnc1870;status=candidate
NC_016810.1	misc_sources	sRNA	1153745	1153841	.	+	.	locus_tag=ncRNA0271;name=STnc1880;status=candidate
NC_016810.1	misc_sources	sRNA	2250891	2250936	.	+	.	locus_tag=ncRNA0272;name=STnc1890;status=candidate
NC_016810.1	misc_sources	sRNA	2756549	2756647	.	+	.	locus_tag=ncRNA0273;name=STnc1920;status=candidate
NC_016810.1	misc_sources	sRNA	1294843	1294986	.	+	.	locus_tag=ncRNA0274;name=STnc1990;status=candidate
NC_016810.1	misc_sources	sRNA	1204289	1204375	.	-	.	locus_tag=ncRNA0275;name=STnc2000;status=candidate
NC_016810.1	misc_sources	sRNA	1353824	1353961	.	+	.	locus_tag=ncRNA0276;name=STnc2010;status=candidate
NC_016810.1	misc_sources	sRNA	1784648	1784727	.	+	.	locus_tag=ncRNA0277;name=STnc2030;status=candidate
NC_016810.1	misc_sources	sRNA	1819355	1819407	.	-	.	locus_tag=ncRNA0278;name=STnc2040;status=confirmed
NC_016810.1	misc_sources	sRNA	2672472	2672567	.	-	.	locus_tag=ncRNA0279;name=STnc2070;status=confirmed
NC_016810.1	misc_sources	sRNA	2759412	2759518	.	-	.	locus_tag=ncRNA0280;name=STnc2080;status=candidate
NC_016810.1	misc_sources	sRNA	2808307	2808466	.	+	.	locus_tag=ncRNA0281;name=STnc2090;status=confirmed
NC_016810.1	misc_sources	sRNA	3550905	3550967	.	+	.	locus_tag=ncRNA0282;name=STnc2100;status=candidate
NC_016810.1	misc_sources	sRNA	4030647	4030694	.	-	.	locus_tag=ncRNA0283;name=STnc2110;status=candidate
NC_016810.1	misc_sources	sRNA	4475779	4475869	.	+	.	locus_tag=ncRNA0284;name=STnc2130;status=confirmed
NC_016810.1	misc_sources	sRNA	4683637	4683699	.	-	.	locus_tag=ncRNA0285;name=STnc2160;status=candidate
NC_016810.1	misc_sources	sRNA	1553671	1553725	.	-	.	locus_tag=ncRNA0286;name=STnc2170;status=candidate
NC_016810.1	misc_sources	sRNA	1568856	1568928	.	-	.	locus_tag=ncRNA0287;name=STnc2175;status=candidate
NC_016810.1	misc_sources	sRNA	1992864	1992915	.	-	.	locus_tag=ncRNA0288;name=STnc2180;status=candidate
NC_016810.1	misc_sources	sRNA	4591418	4591510	.	+	.	locus_tag=ncRNA0289;name=STnc3000;status=candidate
NC_016810.1	misc_sources	sRNA	3038687	3038786	.	+	.	locus_tag=ncRNA0290;name=STnc3020;status=candidate
NC_016810.1	misc_sources	sRNA	3250106	3250210	.	+	.	locus_tag=ncRNA0291;name=STnc3030;status=candidate
NC_016810.1	misc_sources	sRNA	1198646	1198752	.	+	.	locus_tag=ncRNA0292;name=STnc3040;status=candidate
NC_016810.1	misc_sources	sRNA	3533708	3533790	.	+	.	locus_tag=ncRNA0293;name=STnc3060;status=candidate
NC_016810.1	misc_sources	sRNA	2851167	2851225	.	-	.	locus_tag=ncRNA0294;name=STnc3070;status=candidate
NC_016810.1	misc_sources	sRNA	2974260	2974404	.	-	.	locus_tag=ncRNA0295;name=STnc3080;status=candidate
NC_016810.1	misc_sources	sRNA	66916	67048	.	+	.	locus_tag=ncRNA0296;name=STnc3090;status=candidate
NC_016810.1	misc_sources	sRNA	245838	245954	.	+	.	locus_tag=ncRNA0297;name=STnc3100;status=candidate
NC_016810.1	misc_sources	sRNA	249153	249277	.	+	.	locus_tag=ncRNA0298;name=STnc3110;status=candidate
NC_016810.1	misc_sources	sRNA	4249942	4250111	.	+	.	locus_tag=ncRNA0299;name=STnc3120;status=candidate
NC_016810.1	misc_sources	sRNA	3109885	3109981	.	-	.	locus_tag=ncRNA0300;name=STnc3140;status=candidate
NC_016810.1	misc_sources	sRNA	3273500	3273824	.	-	.	locus_tag=ncRNA0301;name=STnc3150;status=candidate
NC_016810.1	misc_sources	sRNA	2807823	2807900	.	-	.	locus_tag=ncRNA0302;name=STnc3160;status=candidate
NC_016810.1	misc_sources	sRNA	4070922	4071037	.	-	.	locus_tag=ncRNA0303;name=STnc3170;status=candidate
NC_016810.1	misc_sources	sRNA	668611	668715	.	+	.	locus_tag=ncRNA0304;name=STnc3180;status=candidate
NC_016810.1	misc_sources	sRNA	16445	16493	.	-	.	locus_tag=ncRNA0305;name=STnc3200;status=candidate
NC_016810.1	misc_sources	sRNA	17025	17111	.	+	.	locus_tag=ncRNA0306;name=STnc3210;status=candidate
NC_016810.1	misc_sources	sRNA	61807	62034	.	+	.	locus_tag=ncRNA0307;name=STnc3220;status=candidate
NC_016810.1	misc_sources	sRNA	74891	75015	.	-	.	locus_tag=ncRNA0308;name=STnc3230;status=candidate
NC_016810.1	misc_sources	sRNA	376115	376194	.	+	.	locus_tag=ncRNA0309;name=STnc3270;status=candidate
NC_016810.1	misc_sources	sRNA	418336	418463	.	-	.	locus_tag=ncRNA0310;name=STnc3280;status=candidate
NC_016810.1	misc_sources	sRNA	738320	738476	.	+	.	locus_tag=ncRNA0311;name=STnc3290;status=candidate
NC_016810.1	misc_sources	sRNA	748526	748639	.	-	.	locus_tag=ncRNA0312;name=STnc3300;status=candidate
NC_016810.1	misc_sources	sRNA	1009199	1009379	.	-	.	locus_tag=ncRNA0313;name=STnc3310;status=candidate
NC_016810.1	misc_sources	sRNA	1024493	1024591	.	-	.	locus_tag=ncRNA0314;name=STnc3330;status=candidate
NC_016810.1	misc_sources	sRNA	863329	863391	.	-	.	locus_tag=ncRNA0315;name=STnc3340;status=candidate
NC_016810.1	misc_sources	sRNA	1047890	1048059	.	+	.	locus_tag=ncRNA0316;name=STnc3350;status=candidate
NC_016810.1	misc_sources	sRNA	1154915	1155001	.	+	.	locus_tag=ncRNA0317;name=STnc3400;status=candidate
NC_016810.1	misc_sources	sRNA	1254996	1255077	.	-	.	locus_tag=ncRNA0318;name=STnc3410;status=candidate
NC_016810.1	misc_sources	sRNA	1289667	1289799	.	-	.	locus_tag=ncRNA0319;name=STnc3420;status=candidate
NC_016810.1	misc_sources	sRNA	1294946	1295057	.	-	.	locus_tag=ncRNA0320;name=STnc3430;status=candidate
NC_016810.1	misc_sources	sRNA	1303294	1303380	.	+	.	locus_tag=ncRNA0321;name=STnc3440;status=candidate
NC_016810.1	misc_sources	sRNA	1363845	1363959	.	+	.	locus_tag=ncRNA0322;name=STnc3460;status=candidate
NC_016810.1	misc_sources	sRNA	1519287	1519550	.	+	.	locus_tag=ncRNA0323;name=STnc3480;status=candidate
NC_016810.1	misc_sources	sRNA	4395573	4395691	.	-	.	locus_tag=ncRNA0324;name=STnc3490;status=candidate
NC_016810.1	misc_sources	sRNA	1495398	1495512	.	+	.	locus_tag=ncRNA0325;name=STnc3500;status=candidate
NC_016810.1	misc_sources	sRNA	1506478	1506597	.	-	.	locus_tag=ncRNA0326;name=STnc3510;status=candidate
NC_016810.1	misc_sources	sRNA	1605698	1605912	.	-	.	locus_tag=ncRNA0327;name=STnc3540;status=candidate
NC_016810.1	misc_sources	sRNA	689832	689990	.	-	.	locus_tag=ncRNA0328;name=STnc3550;status=candidate
NC_016810.1	misc_sources	sRNA	1798672	1798838	.	+	.	locus_tag=ncRNA0329;name=STnc3580;status=candidate
NC_016810.1	misc_sources	sRNA	1812089	1812328	.	+	.	locus_tag=ncRNA0330;name=STnc3600;status=candidate
NC_016810.1	misc_sources	sRNA	1850046	1850400	.	-	.	locus_tag=ncRNA0331;name=STnc3610;status=candidate
NC_016810.1	misc_sources	sRNA	1866668	1866855	.	+	.	locus_tag=ncRNA0332;name=STnc3620;status=candidate
NC_016810.1	misc_sources	sRNA	1894039	1894125	.	+	.	locus_tag=ncRNA0333;name=STnc3630;status=candidate
NC_016810.1	misc_sources	sRNA	1915824	1916082	.	+	.	locus_tag=ncRNA0334;name=STnc3640;status=candidate
NC_016810.1	misc_sources	sRNA	2088048	2088176	.	+	.	locus_tag=ncRNA0335;name=STnc3680;status=candidate
NC_016810.1	misc_sources	sRNA	2131885	2131995	.	+	.	locus_tag=ncRNA0336;name=STnc3700;status=candidate
NC_016810.1	misc_sources	sRNA	2264259	2264328	.	+	.	locus_tag=ncRNA0337;name=STnc3720;status=candidate
NC_016810.1	misc_sources	sRNA	2449087	2449281	.	-	.	locus_tag=ncRNA0338;name=STnc3730;status=candidate
NC_016810.1	misc_sources	sRNA	2503724	2503803	.	-	.	locus_tag=ncRNA0339;name=STnc3750;status=candidate
NC_016810.1	misc_sources	sRNA	2743288	2743373	.	+	.	locus_tag=ncRNA0340;name=STnc3770;status=candidate
NC_016810.1	misc_sources	sRNA	2810663	2810743	.	+	.	locus_tag=ncRNA0341;name=STnc3790;status=candidate
NC_016810.1	misc_sources	sRNA	2824673	2824885	.	-	.	locus_tag=ncRNA0342;name=STnc3800;status=candidate
NC_016810.1	misc_sources	sRNA	3186441	3186534	.	-	.	locus_tag=ncRNA0343;name=STnc3830;status=candidate
NC_016810.1	misc_sources	sRNA	3275931	3276099	.	-	.	locus_tag=ncRNA0344;name=STnc3850;status=candidate
NC_016810.1	misc_sources	sRNA	3283748	3283846	.	-	.	locus_tag=ncRNA0345;name=STnc3860;status=candidate
NC_016810.1	misc_sources	sRNA	3296886	3297024	.	-	.	locus_tag=ncRNA0346;name=STnc3870;status=candidate
NC_016810.1	misc_sources	sRNA	3305410	3305514	.	+	.	locus_tag=ncRNA0347;name=STnc3880;status=candidate
NC_016810.1	misc_sources	sRNA	3322951	3323039	.	+	.	locus_tag=ncRNA0348;name=STnc3890;status=candidate
NC_016810.1	misc_sources	sRNA	3349508	3349727	.	+	.	locus_tag=ncRNA0349;name=STnc3920;status=candidate
NC_016810.1	misc_sources	sRNA	3480987	3481116	.	-	.	locus_tag=ncRNA0350;name=STnc3950;status=candidate
NC_016810.1	misc_sources	sRNA	3491490	3491596	.	+	.	locus_tag=ncRNA0351;name=STnc3960;status=candidate
NC_016810.1	misc_sources	sRNA	3507594	3507677	.	-	.	locus_tag=ncRNA0352;name=STnc3970;status=candidate
NC_016810.1	misc_sources	sRNA	3587262	3587429	.	-	.	locus_tag=ncRNA0353;name=STnc3990;status=candidate
NC_016810.1	misc_sources	sRNA	3619657	3619755	.	+	.	locus_tag=ncRNA0354;name=STnc4000;status=candidate
NC_016810.1	misc_sources	sRNA	3729766	3729898	.	+	.	locus_tag=ncRNA0355;name=STnc4010;status=candidate
NC_016810.1	misc_sources	sRNA	3801174	3801277	.	+	.	locus_tag=ncRNA0356;name=STnc4020;status=candidate
NC_016810.1	misc_sources	sRNA	3993821	3993944	.	-	.	locus_tag=ncRNA0357;name=STnc4040;status=candidate
NC_016810.1	misc_sources	sRNA	4334757	4334855	.	-	.	locus_tag=ncRNA0358;name=STnc4070;status=candidate
NC_016810.1	misc_sources	sRNA	4339813	4339929	.	-	.	locus_tag=ncRNA0359;name=STnc4080;status=candidate
NC_016810.1	misc_sources	sRNA	4448720	4448843	.	+	.	locus_tag=ncRNA0360;name=STnc4100;status=candidate
NC_016810.1	misc_sources	sRNA	4562397	4562497	.	+	.	locus_tag=ncRNA0361;name=STnc4110;status=candidate
NC_016810.1	misc_sources	sRNA	4650288	4650410	.	-	.	locus_tag=ncRNA0362;name=STnc4120;status=candidate
NC_016810.1	misc_sources	sRNA	4796788	4796863	.	-	.	locus_tag=ncRNA0363;name=STnc4130;status=candidate
NC_016810.1	misc_sources	sRNA	4846444	4846540	.	-	.	locus_tag=ncRNA0364;name=STnc4140;status=candidate
NC_016810.1	misc_sources	sRNA	436949	437082	.	-	.	locus_tag=ncRNA0365;name=STnc4150;status=candidate
NC_016810.1	misc_sources	sRNA	66919	67051	.	-	.	locus_tag=ncRNA0366;name=STnc4160;status=candidate
NC_016810.1	misc_sources	sRNA	95102	95188	.	+	.	locus_tag=ncRNA0367;name=STnc4170;status=candidate
NC_016810.1	misc_sources	sRNA	209868	209971	.	-	.	locus_tag=ncRNA0368;name=STnc4190;status=candidate
NC_016810.1	misc_sources	sRNA	1055773	1055892	.	+	.	locus_tag=ncRNA0369;name=STnc4200;status=candidate
NC_016810.1	misc_sources	sRNA	1363927	1363997	.	-	.	locus_tag=ncRNA0370;name=STnc4210;status=candidate
NC_016810.1	misc_sources	sRNA	1464776	1464883	.	-	.	locus_tag=ncRNA0371;name=STnc4220;status=candidate
NC_016810.1	misc_sources	sRNA	2831959	2832046	.	+	.	locus_tag=ncRNA0372;name=STnc4230;status=candidate
NC_016810.1	misc_sources	sRNA	3037101	3037394	.	+	.	locus_tag=ncRNA0373;name=STnc4240;status=candidate
NC_016810.1	misc_sources	sRNA	4069296	4069505	.	+	.	locus_tag=ncRNA0374;name=STnc4250;status=candidate
NC_016810.1	misc_sources	sRNA	4791124	4791239	.	+	.	locus_tag=ncRNA0375;name=STnc4260;status=candidate
NC_016810.1	misc_sources	sRNA	95264	95384	.	-	.	locus_tag=ncRNA0376;name=SLnc0002;status=candidate
NC_016810.1	misc_sources	sRNA	1141185	1141393	.	-	.	locus_tag=ncRNA0377;name=SLnc0010;status=candidate
NC_016810.1	misc_sources	sRNA	1141185	1141397	.	+	.	locus_tag=ncRNA0378;name=SLnc0010a;status=candidate
NC_016810.1	misc_sources	sRNA	1290168	1290467	.	+	.	locus_tag=ncRNA0379;name=SLnc0014;status=candidate
NC_016810.1	misc_sources	sRNA	2073050	2073339	.	+	.	locus_tag=ncRNA0380;name=SLnc0022;status=candidate
NC_016810.1	misc_sources	sRNA	3260147	3260233	.	-	.	locus_tag=ncRNA0381;name=SLnc0030;status=candidate
NC_016810.1	misc_sources	sRNA	3260146	3260230	.	+	.	locus_tag=ncRNA0382;name=SLnc0030a;status=candidate
NC_016810.1	misc_sources	sRNA	3543523	3543651	.	-	.	locus_tag=ncRNA0383;name=SLnc0031;status=candidate
NC_016810.1	misc_sources	sRNA	3924034	3924166	.	-	.	locus_tag=ncRNA0384;name=SLnc0035;status=candidate
NC_016810.1	misc_sources	sRNA	4776443	4776588	.	-	.	locus_tag=ncRNA0385;name=SLnc0039;status=confirmed
NC_016810.1	misc_sources	sRNA	1492616	1492703	.	+	.	locus_tag=ncRNA0386;name=SLnc0048;status=candidate
NC_016810.1	misc_sources	sRNA	808314	808360	.	-	.	locus_tag=ncRNA0387;name=SLnc1001;status=candidate
NC_016810.1	misc_sources	sRNA	905985	906201	.	+	.	locus_tag=ncRNA0388;name=SLnc1002;status=candidate
NC_016810.1	misc_sources	sRNA	2285422	2285656	.	+	.	locus_tag=ncRNA0389;name=SLnc1029;status=candidate
NC_016810.1	misc_sources	sRNA	1564399	1564512	.	+	.	locus_tag=ncRNA0390;name=SLnc1006;status=candidate
NC_016810.1	misc_sources	sRNA	1803615	1803726	.	+	.	locus_tag=ncRNA0391;name=SLnc1008;status=candidate
NC_016810.1	misc_sources	sRNA	2441614	2441698	.	+	.	locus_tag=ncRNA0392;name=SLnc1013;status=candidate
NC_016810.1	misc_sources	sRNA	2441614	2441699	.	-	.	locus_tag=ncRNA0393;name=SLnc1014;status=candidate
NC_016810.1	misc_sources	sRNA	2459769	2459846	.	+	.	locus_tag=ncRNA0394;name=SLnc1015;status=candidate
NC_016810.1	misc_sources	sRNA	2495035	2495121	.	+	.	locus_tag=ncRNA0395;name=SLnc1016;status=candidate
NC_016810.1	misc_sources	sRNA	2495038	2495083	.	-	.	locus_tag=ncRNA0396;name=SLnc1017;status=candidate
NC_016810.1	misc_sources	sRNA	2511303	2511417	.	+	.	locus_tag=ncRNA0397;name=SLnc1018;status=candidate
NC_016810.1	misc_sources	sRNA	2548232	2548289	.	-	.	locus_tag=ncRNA0398;name=SLnc1019;status=candidate
NC_016810.1	misc_sources	sRNA	2586881	2587099	.	+	.	locus_tag=ncRNA0399;name=SLnc1021;status=candidate
NC_016810.1	misc_sources	sRNA	2586916	2587100	.	-	.	locus_tag=ncRNA0400;name=SLnc1022;status=candidate
NC_016810.1	misc_sources	sRNA	3145884	3145967	.	-	.	locus_tag=ncRNA0401;name=SLnc1024;status=candidate
NC_016810.1	misc_sources	sRNA	3165637	3165730	.	-	.	locus_tag=ncRNA0402;name=SLnc1025;status=candidate
NC_016810.1	misc_sources	sRNA	3671382	3671450	.	+	.	locus_tag=ncRNA0403;name=SLnc1026;status=candidate
NC_016810.1	misc_sources	sRNA	3981873	3982063	.	+	.	locus_tag=ncRNA0404;name=SLnc1027;status=candidate
NC_016810.1	misc_sources	sRNA	3981875	3982051	.	-	.	locus_tag=ncRNA0405;name=SLnc1028;status=candidate
NC_016810.1	misc_sources	sRNA	638338	638481	.	+	.	locus_tag=ncRNA0406;name=StyR-3;status=confirmed
NC_016810.1	misc_sources	sRNA	3943835	3943917	.	-	.	locus_tag=ncRNA0407;name=StyR-8;status=candidate
NC_016810.1	misc_sources	sRNA	982113	982272	.	+	.	locus_tag=ncRNA0408;name=StyR-24a;status=candidate
NC_016810.1	misc_sources	sRNA	1271409	1271566	.	+	.	locus_tag=ncRNA0409;name=StyR-24b;status=candidate
NC_016810.1	misc_sources	sRNA	1872027	1872186	.	-	.	locus_tag=ncRNA0410;name=StyR-24c;status=candidate
NC_016810.1	misc_sources	sRNA	2003194	2003351	.	-	.	locus_tag=ncRNA0411;name=StyR-24d;status=candidate
NC_016810.1	misc_sources	sRNA	2576935	2577095	.	-	.	locus_tag=ncRNA0412;name=StyR-24e;status=candidate
NC_016810.1	misc_sources	sRNA	3485323	3485485	.	-	.	locus_tag=ncRNA0413;name=StyR-24f;status=candidate
NC_016810.1	misc_sources	sRNA	3656569	3656727	.	-	.	locus_tag=ncRNA0414;name=StyR-24g;status=candidate
NC_016810.1	misc_sources	sRNA	3889079	3889229	.	-	.	locus_tag=ncRNA0415;name=StyR-27;status=confirmed
NC_016810.1	misc_sources	sRNA	52537	52672	.	-	.	locus_tag=ncRNA0416;name=StyR-29;status=confirmed
NC_016810.1	misc_sources	sRNA	291072	291217	.	+	.	locus_tag=ncRNA0417;name=StyR-44a;status=confirmed
NC_016810.1	misc_sources	sRNA	2800185	2800329	.	-	.	locus_tag=ncRNA0418;name=StyR-44b;status=confirmed
NC_016810.1	misc_sources	sRNA	3591601	3591745	.	-	.	locus_tag=ncRNA0419;name=StyR-44c;status=confirmed
NC_016810.1	misc_sources	sRNA	4123183	4123327	.	+	.	locus_tag=ncRNA0420;name=StyR-44d;status=confirmed
NC_016810.1	misc_sources	sRNA	4219508	4219651	.	+	.	locus_tag=ncRNA0421;name=StyR-44e;status=confirmed
NC_016810.1	misc_sources	sRNA	4374472	4374615	.	+	.	locus_tag=ncRNA0422;name=StyR-44f;status=confirmed
NC_016810.1	misc_sources	sRNA	4417752	4417894	.	+	.	locus_tag=ncRNA0423;name=StyR-44g;status=confirmed
NC_016810.1	misc_sources	sRNA	176086	176169	.	+	.	locus_tag=ncRNA0424;name=StyR-51;status=confirmed
NC_016810.1	misc_sources	sRNA	4385776	4385866	.	+	.	locus_tag=ncRNA0425;name=StyR-55;status=confirmed
NC_016810.1	misc_sources	sRNA	2681155	2681263	.	-	.	locus_tag=ncRNA0426;name=StyR-88;status=confirmed
NC_016810.1	misc_sources	sRNA	935790	935878	.	-	.	locus_tag=ncRNA0427;name=StyR-90;status=confirmed
NC_016810.1	misc_sources	sRNA	2837604	2837643	.	+	.	locus_tag=ncRNA0428;name=StyR-99;status=candidate
NC_016810.1	misc_sources	sRNA	982000	982107	.	-	.	locus_tag=ncRNA0429;name=StyR-103a;status=confirmed
NC_016810.1	misc_sources	sRNA	1271296	1271403	.	-	.	locus_tag=ncRNA0430;name=StyR-103b;status=confirmed
NC_016810.1	misc_sources	sRNA	1872192	1872299	.	+	.	locus_tag=ncRNA0431;name=StyR-103c;status=confirmed
NC_016810.1	misc_sources	sRNA	2003357	2003464	.	+	.	locus_tag=ncRNA0432;name=StyR-103d;status=confirmed
NC_016810.1	misc_sources	sRNA	2577101	2577208	.	+	.	locus_tag=ncRNA0433;name=StyR-103e;status=confirmed
NC_016810.1	misc_sources	sRNA	3485491	3485598	.	+	.	locus_tag=ncRNA0434;name=StyR-103f;status=confirmed
NC_016810.1	misc_sources	sRNA	3656733	3656840	.	+	.	locus_tag=ncRNA0435;name=StyR-103g;status=confirmed
NC_016810.1	misc_sources	sRNA	4479646	4479670	.	+	.	locus_tag=ncRNA0436;name=StyR-122;status=confirmed
NC_016810.1	misc_sources	sRNA	693987	694033	.	+	.	locus_tag=ncRNA0437;name=StyR-126;status=confirmed
NC_016810.1	misc_sources	sRNA	2972113	2972195	.	-	.	locus_tag=ncRNA0438;name=StyR-128;status=candidate
NC_016810.1	misc_sources	sRNA	4359419	4359485	.	-	.	locus_tag=ncRNA0439;name=StyR-134;status=candidate
NC_016810.1	misc_sources	sRNA	2871454	2871499	.	+	.	locus_tag=ncRNA0440;name=StyR-137;status=confirmed
NC_016810.1	misc_sources	sRNA	241227	241270	.	+	.	locus_tag=ncRNA0441;name=StyR-150;status=candidate
NC_016810.1	misc_sources	sRNA	441095	441126	.	+	.	locus_tag=ncRNA0442;name=StyR-169;status=confirmed
NC_016810.1	misc_sources	sRNA	2352626	2352682	.	+	.	locus_tag=ncRNA0443;name=StyR-172;status=candidate
NC_016810.1	misc_sources	sRNA	639906	639939	.	+	.	locus_tag=ncRNA0444;name=StyR-178;status=candidate
NC_016810.1	misc_sources	sRNA	4318834	4318914	.	-	.	locus_tag=ncRNA0445;name=StyR-195;status=confirmed
NC_016810.1	misc_sources	sRNA	2272954	2273035	.	+	.	locus_tag=ncRNA0446;name=StyR-196;status=confirmed
NC_016810.1	misc_sources	sRNA	120107	120156	.	+	.	locus_tag=ncRNA0447;name=StyR-199;status=confirmed
NC_016810.1	misc_sources	sRNA	288995	289054	.	+	.	locus_tag=ncRNA0448;name=StyR-215a;status=candidate
NC_016810.1	misc_sources	sRNA	2802189	2802250	.	-	.	locus_tag=ncRNA0449;name=StyR-215b;status=candidate
NC_016810.1	misc_sources	sRNA	3593605	3593666	.	-	.	locus_tag=ncRNA0450;name=StyR-215c;status=candidate
NC_016810.1	misc_sources	sRNA	4121267	4121323	.	+	.	locus_tag=ncRNA0451;name=StyR-215d;status=candidate
NC_016810.1	misc_sources	sRNA	4217432	4217488	.	+	.	locus_tag=ncRNA0452;name=StyR-215e;status=candidate
NC_016810.1	misc_sources	sRNA	4372396	4372452	.	+	.	locus_tag=ncRNA0453;name=StyR-215f;status=candidate
NC_016810.1	misc_sources	sRNA	4415831	4415892	.	+	.	locus_tag=ncRNA0454;name=StyR-215g;status=candidate
NC_016810.1	misc_sources	sRNA	3221493	3221564	.	+	.	locus_tag=ncRNA0455;name=StyR-219;status=confirmed
NC_016810.1	misc_sources	sRNA	969177	969251	.	+	.	locus_tag=ncRNA0456;name=StyR-222;status=candidate
NC_016810.1	misc_sources	sRNA	3391483	3391601	.	+	.	locus_tag=ncRNA0457;name=StyR-234;status=candidate
NC_016810.1	misc_sources	sRNA	4365232	4365397	.	-	.	locus_tag=ncRNA0458;name=StyR-243;status=confirmed
NC_016810.1	misc_sources	sRNA	1502537	1502747	.	+	.	locus_tag=ncRNA0459;name=StyR-248;status=confirmed
NC_016810.1	misc_sources	sRNA	4309392	4309613	.	-	.	locus_tag=ncRNA0460;name=StyR-250;status=candidate
NC_016810.1	misc_sources	sRNA	1730724	1730885	.	-	.	locus_tag=ncRNA0461;name=StyR-252;status=candidate
NC_016810.1	misc_sources	sRNA	1780981	1781078	.	-	.	locus_tag=ncRNA0462;name=StyR-254;status=confirmed
NC_016810.1	misc_sources	sRNA	2445310	2445474	.	-	.	locus_tag=ncRNA0463;name=StyR-262;status=candidate
NC_016810.1	misc_sources	sRNA	2787531	2787615	.	-	.	locus_tag=ncRNA0464;name=StyR-264;status=confirmed
NC_016810.1	misc_sources	sRNA	2310819	2311125	.	-	.	locus_tag=ncRNA0465;name=StyR-277;status=candidate
NC_016810.1	misc_sources	sRNA	1894421	1894673	.	+	.	locus_tag=ncRNA0466;name=StyR-281;status=confirmed
NC_016810.1	misc_sources	sRNA	1294019	1294128	.	-	.	locus_tag=ncRNA0467;name=StyR-285;status=candidate
NC_016810.1	misc_sources	sRNA	739998	740059	.	-	.	locus_tag=ncRNA0468;name=StyR-287;status=candidate
NC_016810.1	misc_sources	sRNA	1883981	1884041	.	-	.	locus_tag=ncRNA0469;name=StyR-291;status=candidate
NC_016810.1	misc_sources	sRNA	1574607	1574644	.	+	.	locus_tag=ncRNA0470;name=StyR-292;status=candidate
NC_016810.1	misc_sources	sRNA	1832636	1832692	.	-	.	locus_tag=ncRNA0471;name=StyR-293;status=candidate
NC_016810.1	misc_sources	sRNA	6399	6507	.	+	.	locus_tag=ncRNA0472;name=StyR-295;status=candidate
NC_016810.1	misc_sources	sRNA	3758033	3758323	.	-	.	locus_tag=ncRNA0473;name=StyR-296;status=confirmed
NC_016810.1	misc_sources	sRNA	4781745	4781766	.	-	.	locus_tag=ncRNA0474;name=StyR-302;status=candidate
NC_016810.1	misc_sources	sRNA	847583	847697	.	+	.	locus_tag=ncRNA0475;name=StyR-305;status=candidate
NC_016810.1	misc_sources	sRNA	1204044	1204124	.	-	.	locus_tag=ncRNA0476;name=StyR-306;status=confirmed
NC_016810.1	misc_sources	sRNA	4539670	4539738	.	-	.	locus_tag=ncRNA0477;name=StyR-315;status=candidate
NC_016810.1	misc_sources	sRNA	486531	486701	.	+	.	locus_tag=ncRNA0478;name=StyR-322;status=candidate
NC_016810.1	misc_sources	sRNA	1440136	1440315	.	+	.	locus_tag=ncRNA0479;name=StyR-327;status=confirmed
NC_016810.1	misc_sources	sRNA	4264645	4264722	.	+	.	locus_tag=ncRNA0480;name=StyR-328;status=candidate
NC_016810.1	misc_sources	sRNA	4081219	4081302	.	-	.	locus_tag=ncRNA0481;name=StyR-329a;status=confirmed
NC_016810.1	misc_sources	sRNA	4426270	4426340	.	+	.	locus_tag=ncRNA0482;name=StyR-329b;status=confirmed
NC_016810.1	misc_sources	sRNA	3781032	3781134	.	-	.	locus_tag=ncRNA0483;name=StyR-336;status=candidate
NC_016810.1	misc_sources	sRNA	328467	328520	.	-	.	locus_tag=ncRNA0484;name=StyR-341;status=candidate
NC_016810.1	misc_sources	sRNA	4810323	4810368	.	-	.	locus_tag=ncRNA0485;name=StyR-354;status=candidate
NC_016810.1	misc_sources	sRNA	751572	751684	.	+	.	locus_tag=ncRNA0486;name=StyR-358;status=confirmed
NC_016810.1	misc_sources	sRNA	1368274	1368412	.	+	.	locus_tag=ncRNA0487;name=StyR-362;status=candidate
NC_016810.1	misc_sources	sRNA	2716868	2716983	.	+	.	locus_tag=ncRNA0488;name=StyR-369;status=candidate
NC_016810.1	misc_sources	sRNA	4481095	4481209	.	+	.	locus_tag=ncRNA0489;name=StyR-377;status=candidate
NC_016810.1	misc_sources	sRNA	2981218	2981240	.	-	.	locus_tag=ncRNA0490;name=StyR-378;status=candidate
NC_016810.1	misc_sources	sRNA	5014	5162	.	+	.	locus_tag=ncRNA0491;name=RUF_107c.105;status=candidate
NC_016810.1	misc_sources	sRNA	101262	101488	.	-	.	locus_tag=ncRNA0492;name=RUF_107c.1;status=candidate
NC_016810.1	misc_sources	sRNA	109242	109324	.	-	.	locus_tag=ncRNA0493;name=RUF_107c.2;status=candidate
NC_016810.1	misc_sources	sRNA	223450	223563	.	+	.	locus_tag=ncRNA0494;name=RUF_107c.19;status=candidate
NC_016810.1	misc_sources	sRNA	2515425	2515664	.	+	.	locus_tag=ncRNA0495;name=RUF_107c.107;status=candidate
NC_016810.1	misc_sources	sRNA	2462091	2462185	.	-	.	locus_tag=ncRNA0496;name=RUF_107c.108;status=candidate
NC_016810.1	misc_sources	sRNA	2381315	2381496	.	+	.	locus_tag=ncRNA0497;name=RUF_107c.111;status=candidate
NC_016810.1	misc_sources	sRNA	2368367	2368466	.	+	.	locus_tag=ncRNA0498;name=RUF_107c.112;status=candidate
NC_016810.1	misc_sources	sRNA	2285557	2285752	.	-	.	locus_tag=ncRNA0499;name=RUF_111;status=candidate
NC_016810.1	misc_sources	sRNA	2012798	2012914	.	-	.	locus_tag=ncRNA0500;name=RUF_121;status=candidate
NC_016810.1	misc_sources	sRNA	1972226	1972265	.	-	.	locus_tag=ncRNA0501;name=RUF_125;status=candidate
NC_016810.1	misc_sources	sRNA	1325422	1325551	.	+	.	locus_tag=ncRNA0502;name=RUF_341c.2;status=candidate
NC_016810.1	misc_sources	sRNA	1212658	1212715	.	+	.	locus_tag=ncRNA0503;name=RUF_107c.8;status=candidate
NC_016810.1	misc_sources	sRNA	1041280	1041377	.	+	.	locus_tag=ncRNA0504;name=RUF_107c.10;status=candidate
NC_016810.1	misc_sources	sRNA	1014991	1015135	.	-	.	locus_tag=ncRNA0505;name=RUF_167;status=candidate
NC_016810.1	misc_sources	sRNA	765332	765503	.	-	.	locus_tag=ncRNA0506;name=RUF_178;status=candidate
NC_016810.1	misc_sources	sRNA	731995	732186	.	+	.	locus_tag=ncRNA0507;name=RUF_107c.18;status=candidate
NC_016810.1	misc_sources	sRNA	563424	563507	.	-	.	locus_tag=ncRNA0508;name=RUF_107c.23;status=candidate
NC_016810.1	misc_sources	sRNA	554741	554803	.	+	.	locus_tag=ncRNA0509;name=RUF_107c.24;status=candidate
NC_016810.1	misc_sources	sRNA	545301	545385	.	-	.	locus_tag=ncRNA0510;name=RUF_107c.26;status=candidate
NC_016810.1	misc_sources	sRNA	485618	485703	.	+	.	locus_tag=ncRNA0511;name=RUF_107c.30;status=candidate
NC_016810.1	misc_sources	sRNA	2950529	2950709	.	-	.	locus_tag=ncRNA0512;name=RUF_341c.10;status=candidate
NC_016810.1	misc_sources	sRNA	3004047	3004210	.	+	.	locus_tag=ncRNA0513;name=RUF_341c.11;status=candidate
NC_016810.1	misc_sources	sRNA	3034326	3034476	.	-	.	locus_tag=ncRNA0514;name=RUF_219c;status=candidate
NC_016810.1	misc_sources	sRNA	3035626	3035825	.	-	.	locus_tag=ncRNA0515;name=RUF_220c;status=candidate
NC_016810.1	misc_sources	sRNA	3138371	3138506	.	+	.	locus_tag=ncRNA0516;name=RUF_226;status=candidate
NC_016810.1	misc_sources	sRNA	3165601	3165676	.	+	.	locus_tag=ncRNA0517;name=RUF_107c.38;status=candidate
NC_016810.1	misc_sources	sRNA	3488778	3489090	.	-	.	locus_tag=ncRNA0518;name=RUF_247c;status=candidate
NC_016810.1	misc_sources	sRNA	3497979	3498072	.	-	.	locus_tag=ncRNA0519;name=RUF_107c.47;status=candidate
NC_016810.1	misc_sources	sRNA	3555600	3555808	.	+	.	locus_tag=ncRNA0520;name=RUF_107c.50;status=candidate
NC_016810.1	misc_sources	sRNA	3557225	3557323	.	-	.	locus_tag=ncRNA0521;name=RUF_107c.51;status=candidate
NC_016810.1	misc_sources	sRNA	4167484	4167759	.	+	.	locus_tag=ncRNA0522;name=RUF_257c;status=candidate
NC_016810.1	misc_sources	sRNA	4140293	4140495	.	+	.	locus_tag=ncRNA0523;name=RUF_107c.53;status=candidate
NC_016810.1	misc_sources	sRNA	4354659	4354777	.	-	.	locus_tag=ncRNA0524;name=RUF_107c.56;status=candidate
NC_016810.1	misc_sources	sRNA	4313620	4313825	.	+	.	locus_tag=ncRNA0525;name=RUF_107c.57;status=candidate
NC_016810.1	misc_sources	sRNA	4311608	4311707	.	-	.	locus_tag=ncRNA0526;name=RUF_107c.58;status=candidate
NC_016810.1	misc_sources	sRNA	4294626	4294818	.	+	.	locus_tag=ncRNA0527;name=RUF_107c.59;status=candidate
NC_016810.1	misc_sources	sRNA	4233988	4234067	.	+	.	locus_tag=ncRNA0528;name=RUF_107c.63;status=candidate
NC_016810.1	misc_sources	sRNA	4101944	4102425	.	-	.	locus_tag=ncRNA0529;name=RUF_279;status=candidate
NC_016810.1	misc_sources	sRNA	3965810	3965925	.	+	.	locus_tag=ncRNA0530;name=RUF_107c.69;status=candidate
NC_016810.1	misc_sources	sRNA	3915175	3915452	.	-	.	locus_tag=ncRNA0531;name=RUF_290;status=candidate
NC_016810.1	misc_sources	sRNA	3831527	3831666	.	+	.	locus_tag=ncRNA0532;name=RUF_107c.70;status=candidate
NC_016810.1	misc_sources	sRNA	3773063	3773164	.	+	.	locus_tag=ncRNA0533;name=RUF_107c.72;status=candidate
NC_016810.1	misc_sources	sRNA	3675906	3675975	.	+	.	locus_tag=ncRNA0534;name=RUF_107c.77;status=candidate
NC_016810.1	misc_sources	sRNA	4429386	4429527	.	+	.	locus_tag=ncRNA0535;name=RUF_107c.81;status=candidate
NC_016810.1	misc_sources	sRNA	4463078	4463228	.	+	.	locus_tag=ncRNA0536;name=RUF_107c.82;status=candidate
NC_016810.1	misc_sources	sRNA	4470487	4470622	.	+	.	locus_tag=ncRNA0537;name=RUF_107c.83;status=candidate
NC_016810.1	misc_sources	sRNA	4530497	4530675	.	+	.	locus_tag=ncRNA0538;name=RUF_107c.86;status=candidate
NC_016810.1	misc_sources	sRNA	4545622	4545687	.	+	.	locus_tag=ncRNA0539;name=RUF_107c.89;status=candidate
NC_016810.1	misc_sources	sRNA	4546507	4546655	.	+	.	locus_tag=ncRNA0540;name=RUF_107c.90;status=candidate
NC_016810.1	misc_sources	sRNA	4572956	4572995	.	-	.	locus_tag=ncRNA0541;name=RUF_321c;status=candidate
NC_016810.1	misc_sources	sRNA	4583111	4583153	.	-	.	locus_tag=ncRNA0542;name=RUF_328c;status=candidate
NC_016810.1	misc_sources	sRNA	4660039	4660173	.	-	.	locus_tag=ncRNA0543;name=RUF_107c.92;status=candidate
NC_016810.1	misc_sources	sRNA	4728866	4728981	.	+	.	locus_tag=ncRNA0544;name=RUF_107c.94;status=candidate
NC_016810.1	misc_sources	sRNA	4737458	4737715	.	-	.	locus_tag=ncRNA0545;name=RUF_107c.95;status=candidate
NC_016810.1	misc_sources	sRNA	4745087	4745192	.	+	.	locus_tag=ncRNA0546;name=RUF_107c.96;status=candidate
NC_016810.1	misc_sources	sRNA	4856253	4856395	.	-	.	locus_tag=ncRNA0547;name=RUF_107c.102;status=candidate
EOF
}

extract_salmonella_gene_and_locus_tags(){
    # Generate a CSV file based on the annotations files that has a
    # columns with gene name and locus tag.
    cat $INPUT_FOLDER/NC_01*.gff > tmp_combinded_annotations 
    python bin/add_annotations.py \
        $OUTPUT_FOLDER/Salmonella.gff \
	$INPUT_FOLDER/NC_016810.gff \
	$INPUT_FOLDER/NC_017718.gff \
	$INPUT_FOLDER/NC_017719.gff \
	$INPUT_FOLDER/NC_017720.gff \
	> $OUTPUT_FOLDER/Salmonella.csv
    rm tmp_combinded_annotations
}

download_human_files(){
    wget -c -P $INPUT_FOLDER \
        ftp://ftp.1000genomes.ebi.ac.uk/vol1/ftp/technical/reference/phase2_reference_assembly_sequence/hs37d5.fa.gz

    wget -c -P $INPUT_FOLDER \
    	ftp://ftp.sanger.ac.uk/pub/gencode/Gencode_human/release_19/gencode.v19.annotation.gtf.gz

    # The original NONCODE v4 files used during this study are
    # unfornately not available on the ftp server any more. Due to
    # license reasons (the CC-BY-NC license conflicts with our repo
    # license) we can not add them to this repostorium. Please contact
    # us in case you need them. Alternatively use the available
    # files from NONCODE.
    wget -c -P $INPUT_FOLDER \
        http://www.noncode.org/datadownload/NONCODEv4_hg19.lncAndGene.bed \
        http://www.noncode.org/datadownload/NONCODEv4_human.func.gz \
        http://www.noncode.org/datadownload/NONCODEv4_source.gz \
        http://www.noncode.org/datadownload/NONCODEv4_Transcript2Gene.gz \
        http://www.noncode.org/datadownload/NONCODEv4_human_cc.tgz
    echo "======================="
    echo "Warning! Missing files!"
    echo "======================="

    wget -c -O $INPUT_FOLDER/mirbase_hsa.gff \
    	ftp://mirbase.org/pub/mirbase/20/genomes/hsa.gff3

    wget -P $INPUT_FOLDER \
     	ftp://ftp.sanger.ac.uk/pub/gencode/release_11/gencode.v11.tRNAs.gtf.gz

    gunzip $INPUT_FOLDER/*gz
    tar xfv input/NONCODEv4_human_cc.tar 
    mv human.cc human_rna.cc $INTPUT_FOLDER/
}

convert_human_gtf_to_gff(){
    OUTPUT_FILE=$OUTPUT_FOLDER/gencode.v19.annotation.gff
    echo "##gff-version 3" > $OUTPUT_FILE
    cat $INPUT_FOLDER/gencode.v19.annotation.gtf \
        | sed "s/\"; /;/g" \
        | sed "s/;\ \ /;/g" \
        | sed "s/;\ /;/g" \
        | sed "s/\ /=/g" \
        | sed "s/\"//g" \
        >> $OUTPUT_FILE

    OUTPUT_FILE=$OUTPUT_FOLDER/gencode.v11.tRNAs.gff
    cat $INPUT_FOLDER/gencode.v11.tRNAs.gtf \
        | sed "s/\"; /;/g" \
        | sed "s/;\ \ /;/g" \
        | sed "s/;\ /;/g" \
        | sed "s/\ /=/g" \
        | sed "s/\"//g" \
        | sed "s/level=3;/level=3/g" \
	| sed "s/^chrM/chrMT/" \
        > $OUTPUT_FILE
}

fix_human_fasta_headers(){
    cat $INPUT_FOLDER/hs37d5.fa \
	| sed -r "s/>([[0-9]|X|Y|MT|])/>chr\1/" \
	> $OUTPUT_FOLDER/hs37d5.fa
}

extract_human_noncode_entries(){
    zgrep Human $INPUT_FOLDER/NONCODEv4_source \
        > $OUTPUT_FOLDER/NONCODEv4_source_human_only
}

filter_noncode_entries(){
    python3 bin/filter_noncode_by_gencode.py \
        $OUTPUT_FOLDER/gencode.v19.annotation.gff \
        $INPUT_FOLDER/NONCODEv4_hg19.lncAndGene.bed \
        $OUTPUT_FOLDER/NONCODEv4_source_human_only \
        $INPUT_FOLDER/NONCODEv4_Transcript2Gene \
        $INPUT_FOLDER/human.cc \
        $INPUT_FOLDER/human_rna.cc \
        > $OUTPUT_FOLDER/NONCODEv4_hg19.lncAndGene_selected.gff

    grep -v chr.._ \
        $OUTPUT_FOLDER/NONCODEv4_hg19.lncAndGene_selected.gff \
        | grep -v chr._  > tmp
    mv tmp $OUTPUT_FOLDER/NONCODEv4_hg19.lncAndGene_selected.gff
}

combine_human_annotations_and_remove_redundancies(){
    OUTPUT=$OUTPUT_FOLDER/Human_partly_redundant.gff
    OUTPUT_NONREDUNDANT=$OUTPUT_FOLDER/Human.gff
    # Use only gene entries
    grep -P "\tgene\t" $OUTPUT_FOLDER/gencode.v19.annotation.gff \
    	> $OUTPUT
    grep -P "\tgene\t" $OUTPUT_FOLDER/NONCODEv4_hg19.lncAndGene_selected.gff \
	>> $OUTPUT
    sed -i "s/^chrM/chrMT/" $OUTPUT
    # Remove miRNA
    grep -v "transcript_type=miRNA" $OUTPUT > tmp
    mv tmp $OUTPUT
    # Add miRBase miRNA
    grep -v "#" input/mirbase_hsa.gff \
	| sed "s/\t.\tmiRNA_/\tmiRBASE\tmiRNA_/" \
	>> $OUTPUT
    grep -v "#" $OUTPUT_FOLDER/gencode.v11.tRNAs.gff >> $OUTPUT
    # Add rRNA annotation
    echo "GL000220.1\tmisc_sources\tgene\t1\t161801\t.\t+\t.\tnote=manually_added;gene_type=rRNA;gene_status=KNOWN;transcript_type=rRNA;transcript_status=KNOWN" \
        >> $OUTPUT
    python bin/remove_redundant_noncode_by_position.py $OUTPUT \
	> $OUTPUT_NONREDUNDANT
}

download_pig_files(){
    wget -cP $INPUT_FOLDER \
        ftp://ftp.ensembl.org/pub/release-78/gtf/sus_scrofa/Sus_scrofa.Sscrofa10.2.78.gtf.gz \
        ftp://ftp.ensembl.org/pub/release-78/fasta/sus_scrofa/dna/Sus_scrofa.Sscrofa10.2.dna.*fa.gz
    rm  $INPUT_FOLDER/Sus_scrofa.Sscrofa10.2.dna.toplevel.fa.gz
}

combine_pig_fastas(){
    zcat $INPUT_FOLDER/Sus_scrofa.Sscrofa10.2.dna*fa.gz \
        > $OUTPUT_FOLDER/Pig.fa
}

convert_pig_gtf_to_gff(){
    zcat $INPUT_FOLDER/Sus_scrofa.Sscrofa10.2.78.gtf.gz \
	| sed -e 's/ "/="/g' -e 's/;\ /;/g' -e 's/;$//' -e 's/;";/";/' \
        -e "s/;-/,-/" -e 's/"//g' \
	| grep -P "\tgene\t" \
	> $OUTPUT_FOLDER/Pig.gff
}

download_mouse_file(){
    wget -cP $INPUT_FOLDER \
	ftp://ftp.sanger.ac.uk/pub/gencode/Gencode_mouse/release_M2/GRCm38.p2.genome.fa.gz
}

extract_mouse_file(){
    zcat $INPUT_FOLDER/GRCm38.p2.genome.fa.gz \
    	> $OUTPUT_FOLDER/Mouse.fa
}

main
